| car_models.int | R Documentation |
Interval-valued specifications for 33 Italian car models, classified into 4 categories (Utilitaria, Berlina, Ammiraglia, Sportiva). An extended version of the classic cars interval dataset with 8 interval-valued variables including dimensions.
data(car_models.int)
A data frame with 33 observations and 9 variables:
price: Price range (currency units).
engine_cc: Engine displacement range (cc).
top_speed: Top speed range (km/h).
acceleration: Acceleration range (seconds 0-100 km/h).
wheelbase: Wheelbase range (cm).
length: Length range (cm).
width: Width range (cm).
height: Height range (cm).
class: Car category (Utilitaria, Berlina, Ammiraglia, Sportiva).
| Sample size (n) | 33 |
| Variables (p) | 9 |
| Subject area | Automotive |
| Symbolic format | Interval |
| Analytical tasks | Clustering, Classification |
https://github.com/Natandradesa/Kernel-Clustering-for-Interval-Data
Andrade, N. A., de Carvalho, F. A. T. and Pimentel, B. A. (2025). Kernel clustering with automatic variable weighting for interval data. Neurocomputing, 617, 128954.
data(car_models.int)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.