| fungi.int | R Documentation |
Interval-valued morphological measurements for 55 fungi specimens from 3 genera (Amanita, Agaricus, Boletus). Contains 5 interval-valued variables describing pileus and stipe dimensions and spore characteristics.
data(fungi.int)
A data frame with 55 observations and 6 variables:
pileus_width: Width of the pileus (cap).
stipe_width: Width of the stipe (stem).
stipe_thickness: Thickness of the stipe.
spore_height: Height of the spores.
spore_width: Width of the spores.
class: Fungus genus (Amanita, Agaricus, Boletus).
| Sample size (n) | 55 |
| Variables (p) | 6 |
| Subject area | Biology |
| Symbolic format | Interval |
| Analytical tasks | Clustering |
https://github.com/Natandradesa/Kernel-Clustering-for-Interval-Data
Andrade, N. A., de Carvalho, F. A. T. and Pimentel, B. A. (2025). Kernel clustering with automatic variable weighting for interval data. Neurocomputing, 617, 128954.
data(fungi.int)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.