hdi_gender.int: Human Development Index and Gender Indicators Interval...

hdi_gender.intR Documentation

Human Development Index and Gender Indicators Interval Dataset

Description

Interval-valued World Bank gender indicators for 183 countries, with ordinal HDI classification. Contains interval ranges for Women, Business and the Law Index Score and proportion of seats held by women in national parliaments.

Usage

data(hdi_gender.int)

Format

A data frame with 183 observations and 6 variables:

  • code: ISO 3166-1 alpha-3 country code.

  • country: Country name.

  • hdi: Human Development Index value (UNDP).

  • women_law_index: Women, Business and the Law Index Score range.

  • women_parliament: Proportion of seats held by women in national parliaments range (%).

  • hdi_category: Ordered factor with HDI classification (Low < Medium < High < Very High).

Metadata

Sample size (n) 183
Variables (p) 6
Subject area Socioeconomics
Symbolic format Interval
Analytical tasks Classification

https://github.com/aleixalcacer/OCFIVD

References

Alcacer, A., Barrel, A., Groenen, P. J. F. and Grana, M. (2023). Ordinal classification for interval-valued data and ordinal data. Expert Systems with Applications, 238, 121825.

Examples

data(hdi_gender.int)

dataSDA documentation built on June 12, 2026, 9:06 a.m.