Learn R Programming

dataSDA (version 0.1.8)

health_insurance.mix: Health Insurance Mixed Symbolic Dataset

Description

Health insurance data grouped by disease type and gender with classical and symbolic variables of mixed types.

Usage

data(health_insurance.mix)

Arguments

Format

An object of class data.frame with 51 rows and 30 columns.

References

Billard, L. and Diday, E. (2006). Symbolic Data Analysis. Wiley. Tables 2.1-2.2.

Examples

Run this code
data(health_insurance.mix)

Run the code above in your browser using DataLab