| iris.int | R Documentation |
Interval-valued version of the classic iris dataset, aggregated from Fisher's iris data into 30 interval observations across 3 species (Setosa, Versicolor, Virginica). Each observation represents a group of flowers with ranges for sepal and petal measurements.
data(iris.int)
A data frame with 30 observations and 5 variables:
sepal_length: Sepal length range (cm).
sepal_width: Sepal width range (cm).
petal_length: Petal length range (cm).
petal_width: Petal width range (cm).
class: Species (Setosa, Versicolor, Virginica).
| Sample size (n) | 30 |
| Variables (p) | 5 |
| Subject area | Botany |
| Symbolic format | Interval |
| Analytical tasks | Clustering |
https://github.com/Natandradesa/Kernel-Clustering-for-Interval-Data
Andrade, N. A., de Carvalho, F. A. T. and Pimentel, B. A. (2025). Kernel clustering with automatic variable weighting for interval data. Neurocomputing, 617, 128954.
data(iris.int)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.