lung_cancer.hist: Lung Cancer Treatments by State Histogram-Valued Dataset

lung_cancer.histR Documentation

Lung Cancer Treatments by State Histogram-Valued Dataset

Description

Histogram-valued distribution of lung cancer treatment counts for 2 US states (Massachusetts and New York).

Usage

data(lung_cancer.hist)

Format

A data frame with 2 observations and 2 variables:

  • state: State name (character).

  • y30: Histogram-valued distribution of treatment counts as a weighted set string (e.g., "{0, 0.77; 1, 0.08; 2, 0.15}").

Metadata

Sample size (n) 2
Variables (p) 2
Subject area Medical
Symbolic format Histogram
Analytical tasks Descriptive statistics

References

Billard, L. and Diday, E. (2006). Symbolic Data Analysis. Wiley. Table 2.20.

Examples

data(lung_cancer.hist)

dataSDA documentation built on June 12, 2026, 9:06 a.m.