| ohtemp.int | R Documentation |
Interval-valued dataset of 30-year trimmed mean daily temperatures for the Ohio river basin. Intervals are defined by the mean daily maximum and minimum temperatures from January 1, 1988 to December 31, 2018.
data(ohtemp.int)
A data frame with 161 rows and 7 variables:
ID: Global Historical Climatological Network (GHCN) station identifier.
NAME: GHCN station name.
STATE: Two-digit state designation.
LATITUDE: Latitude coordinate position.
LONGITUDE: Longitude coordinate position.
ELEVATION: Elevation of the measurement location (meters).
TEMPERATURE: 30-year mean daily temperature (tenths of degrees Celsius).
| Sample size (n) | 161 |
| Variables (p) | 7 |
| Subject area | Climate |
| Symbolic format | Interval |
| Analytical tasks | Regression, Spatial analysis |
https://CRAN.R-project.org/package=intkrige
data(ohtemp.int)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.