| prostate.int | R Documentation |
Interval-valued clinical measurements for 97 prostate cancer patients (training and test sets combined). Contains 9 interval-valued variables from log-transformed cancer volume, weight, age, and other clinical predictors.
data(prostate.int)
A data frame with 97 observations and 9 interval-valued variables:
lcavol: Log cancer volume range.
lweight: Log prostate weight range.
age: Patient age range.
lbph: Log benign prostatic hyperplasia amount range.
svi: Seminal vesicle invasion range.
lcp: Log capsular penetration range.
gleason: Gleason score range.
pgg45: Percentage Gleason scores 4 or 5 range.
lpsa: Log prostate specific antigen range.
| Sample size (n) | 97 |
| Variables (p) | 9 |
| Subject area | Medical |
| Symbolic format | Interval |
| Analytical tasks | Regression |
Extracted from RSDA package (int_prost_train, int_prost_test).
Stamey, T. et al. (1989). Prostate specific antigen in the diagnosis and treatment of adenocarcinoma of the prostate. II. Radical prostatectomy treated patients. J. Urology, 141(5), 1076-1083.
data(prostate.int)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.