set_variable_format: Set Variable Format

View source: R/interval_utils.R

set_variable_formatR Documentation

Set Variable Format

Description

This function changes the format of the set variables in the data to conform to the RSDA format.

Usage

set_variable_format(data, location = NULL, var = NULL)

Arguments

data

A conventional data.

location

The location of the set variable in the data.

var

The name of the set variable in the data.

Value

Return a dataframe in which a set variable is converted to one-hot encoding.

Examples

data("mushroom.int.mm")
mushroom.set <- set_variable_format(data = mushroom.int.mm, location = 8, var = "Species")

dataSDA documentation built on June 12, 2026, 9:06 a.m.