| utsnow.int | R Documentation |
Interval-valued ground snow load data from 415 weather stations in Utah and surrounding states. Each observation is a station with a 50-year ground snow load interval (lower and upper bounds of the prediction interval in kPa) plus the point estimate, geographic coordinates, and elevation.
data(utsnow.int)
A symbolic data frame (symbolic_tbl) with 415 observations
and 5 variables:
snow_load: Interval-valued 50-year ground snow load (kPa).
point_estimate: Numeric point estimate (kPa).
latitude: Numeric latitude (degrees).
longitude: Numeric longitude (degrees).
elevation: Numeric elevation (meters).
| Sample size (n) | 415 |
| Variables (p) | 5 |
| Subject area | Climate |
| Symbolic format | Interval |
| Analytical tasks | Regression, Spatial analysis |
intkrige R package (utsnow dataset).
Schmoyer, R. L. (1993). Permutation tests for correlation in regression errors. Journal of the American Statistical Association, 89(428), 1507–1516.
Bean, B., Sun, Y., and Maguire, M. (2022). Interval-valued kriging models for geostatistical mapping with uncertain inputs.
Original data from the intkrige R package (utsnow dataset).
data(utsnow.int)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.