| wine.int | R Documentation |
Interval-valued chemical and physical properties of 33 wine samples classified into 2 groups. Contains 9 interval-valued measurement variables. Used as a benchmark for interval data clustering algorithms.
data(wine.int)
A data frame with 33 observations and 10 variables:
V1 through V9: Nine interval-valued chemical/physical
property measurements.
class: Wine group (1 or 2).
| Sample size (n) | 33 |
| Variables (p) | 10 |
| Subject area | Food science |
| Symbolic format | Interval |
| Analytical tasks | Clustering |
https://github.com/Natandradesa/Kernel-Clustering-for-Interval-Data
Andrade, N. A., de Carvalho, F. A. T. and Pimentel, B. A. (2025). Kernel clustering with automatic variable weighting for interval data. Neurocomputing, 617, 128954.
data(wine.int)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.