| hdi_gender.int | R Documentation |
Interval-valued World Bank gender indicators for 183 countries, with ordinal HDI classification. Contains interval ranges for Women, Business and the Law Index Score and proportion of seats held by women in national parliaments.
data(hdi_gender.int)
A data frame with 183 observations and 6 variables:
code: ISO 3166-1 alpha-3 country code.
country: Country name.
hdi: Human Development Index value (UNDP).
women_law_index: Women, Business and the Law Index Score range.
women_parliament: Proportion of seats held by women in
national parliaments range (%).
hdi_category: Ordered factor with HDI classification
(Low < Medium < High < Very High).
| Sample size (n) | 183 |
| Variables (p) | 6 |
| Subject area | Socioeconomics |
| Symbolic format | Interval |
| Analytical tasks | Classification |
https://github.com/aleixalcacer/OCFIVD
Alcacer, A., Barrel, A., Groenen, P. J. F. and Grana, M. (2023). Ordinal classification for interval-valued data and ordinal data. Expert Systems with Applications, 238, 121825.
data(hdi_gender.int)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.