powered by
Health insurance data grouped by disease type and gender with classical and symbolic variables of mixed types.
data(health_insurance.mix)
An object of class data.frame with 51 rows and 30 columns.
data.frame
Billard, L. and Diday, E. (2006). Symbolic Data Analysis. Wiley. Tables 2.1-2.2.
Run the code above in your browser using DataLab