| loans_by_risk_quantile.int | R Documentation |
Interval-valued dataset of 35 Lending Club loan groups stratified by risk level (A1–G5). Intervals represent the 10th to 90th percentile range of each financial variable within each risk subgrade.
data(loans_by_risk_quantile.int)
A symbolic data frame (symbolic_tbl) with 35 observations
and 4 variables:
ln-inc: Interval-valued log income.
int-rate: Interval-valued interest rate.
open-acc: Interval-valued number of open accounts.
total-acc: Interval-valued total accounts.
| Sample size (n) | 35 |
| Variables (p) | 4 |
| Subject area | Finance |
| Symbolic format | Interval |
| Analytical tasks | Classification, Clustering |
MAINT.Data R package (LoansbyRiskLvs_qntlDt dataset).
Brito, P. and Duarte Silva, A.P. (2012). Modelling interval data with Normal and Skew-Normal distributions. Journal of Applied Statistics, 39(1), 3–20.
Original data from the MAINT.Data R package
(LoansbyRiskLvs_qntlDt dataset).
data(loans_by_risk_quantile.int)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.