| water_flow.int | R Documentation |
Large interval-valued dataset of water flow sensor readings with 316 observations and 47 interval-valued feature variables (IF1-IF48, excluding IF17), classified into 2 groups. Used as a benchmark for interval data clustering with high-dimensional features.
data(water_flow.int)
A data frame with 316 observations and 48 variables:
if1 through if48 (excluding if17): 47 interval-valued
sensor feature measurements.
class: Group label (1 or 2).
| Sample size (n) | 316 |
| Variables (p) | 48 |
| Subject area | Engineering |
| Symbolic format | Interval |
| Analytical tasks | Clustering |
https://github.com/Natandradesa/Kernel-Clustering-for-Interval-Data
Andrade, N. A., de Carvalho, F. A. T. and Pimentel, B. A. (2025). Kernel clustering with automatic variable weighting for interval data. Neurocomputing, 617, 128954.
data(water_flow.int)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.