| world_cup.int | R Documentation |
Interval-valued data for soccer teams grouped by World Cup qualification status (yes/no). Includes age, weight, height ranges and the covariance between weight and height.
data(world_cup.int)
A data frame with 2 observations and 8 variables:
world_cup: Qualification status (yes/no, character).
age_l, age_u: Player age range (years).
weight_l, weight_u: Player weight range (kg).
height_l, height_u: Player height range (meters).
cov_weight_height: Covariance between weight and height (numeric).
| Sample size (n) | 2 |
| Variables (p) | 8 |
| Subject area | Sports |
| Symbolic format | Interval |
| Analytical tasks | Descriptive statistics |
Diday, E. and Noirhomme-Fraiture, M. (Eds.) (2008). Symbolic Data Analysis and the SODAS Software. Wiley. Table 1.9, p.13.
data(world_cup.int)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.